%% tcsme.cls
\NeedsTeXFormat{LaTeX2e}\relax
\ProvidesClass{CCToMM2023Conf}%
[2020/11/11 Style for the 2023 CCToMM M^3]

%% Author: Hans-Peter Schroecker, http://geometrie.uibk.ac.at/schroecker/
%% Modified by: Vincent Duchaine, http://www.etsmtl.ca/Unites-de-recherche/CoRo/accueil?lang=en-CA
%% Modified by: M.J.D. Hayes, https://carleton.ca/mae/people/m-john-d-hayes/
%% Modified by: P. Cardou, https://robot.gmc.ulaval.ca/membres/membres-actuels/philippe-cardou/
%% Load ``scrartcl.cls'', using options ``12pt'' and letter paper
%% size as default options.  Author options are not passed to the
%% class.
\ExecuteOptions{paper=letter,11pt}\relax
\ProcessOptions\relax
\LoadClass[%
  paper=letter,%
  11pt,%
]{scrartcl}

%% Load additional packages

\RequirePackage{ifthen}
\newboolean{englishprimary}
 %\setboolean{englishprimary}{true}
% \setboolean{englishprimary}{false}

\RequirePackage{textcomp}
\RequirePackage{ragged2e}


\RequirePackage[french,english]{babel}
\AtBeginDocument{%
  \ifthenelse{\boolean{englishprimary}}%
  {\selectlanguage{english}}%
  {\selectlanguage{french}}}

% \RequirePackage[left=0.65in,right=0.65in,top=1.18in,bottom=0.60in]{geometry}
\RequirePackage[paper=letterpaper,left=1in,right=1in,top=0.90in,bottom=0.9in,footskip=0.4in,includefoot]{geometry}
\RequirePackage{mathptmx}
\RequirePackage[scaled]{helvet}
\RequirePackage{indentfirst}
\RequirePackage[numbers,sort,compress]{natbib}

\setcapindent{0pt}

\def\tcsmevol{36}
\def\tcsmeno{3}
\def\tcsmeyear{2023}
\def\figurename{Fig.}

\renewenvironment{abstract}{%
  \ifthenelse{\boolean{englishprimary}}{\selectlanguage{english}}{\selectlanguage{french}}
  \noindent
  {\scshape\bfseries
  \ifthenelse{\boolean{englishprimary}}{ABSTRACT}{R\'ESUM\'E}\par}
}{\par}
\newenvironment{abstractb}{%
  \ifthenelse{\boolean{englishprimary}}{\selectlanguage{french}}{\selectlanguage{english}}
  \noindent
  {\scshape\bfseries
  \ifthenelse{\boolean{englishprimary}}{R\'ESUM\'E}{ABSTRACT}\par}
}{\par}

\renewcommand*\maketitle[1][1]{\@maketitle}
\renewcommand*{\@maketitle}{%
  \begin{center}%
    {\normalfont\bfseries\MakeUppercase{\@title} \par}%
    % {\normalfont\bfseries\@title \par}%
    \vspace*{3.9mm}
    {\begin{tabular}[t]{c}
        \@author
      \end{tabular}\par
    }%
    \vspace*{-0.8mm}
    % {\fontsize{11pt}{13.2pt}\selectfont
    %   \itshape\@affiliation \par}%
    {\@affiliation \par}%
    \vspace*{2.5mm}
    % \fontsize{11pt}{13.2pt}\selectfont
    \small
    %Received April 2012, Accepted October 2012\\
    %No. 12-CSME-47, E.I.C. Accession 3367
  \end{center}%
  \par
  \vspace*{-4.5mm}
  \noindent
  \rule{\linewidth}{.4pt}
  \par
  \vspace*{3mm}
}%

\newcommand*{\@affiliation}{}%
\newcommand{\affiliation}[1]{\gdef\@affiliation{%
    % \fontsize{11pt}{13.2pt}\selectfont%
    \small
    {\itshape #1}}}
% \newcommand{\affiliation}[1]{\gdef\@affiliation #1};
\newcommand*{\@etitle}{}%
\newcommand*{\@ftitle}{}%
\newcommand{\etitle}[1]{\gdef\@etitle{#1}}
\newcommand{\ftitle}[1]{\gdef\@ftitle{#1}}
\newcommand{\makeetitle}{
  \noindent
    \\
  \rule[2em]{\linewidth}{.4pt}
  \par\vspace*{-8.7mm}
  \begin{center}%
    {\selectlanguage{english}%
      \normalfont\bfseries%
      \MakeUppercase{\@etitle}%
      \par}%
  \end{center}}
\newcommand{\makeftitle}{
  \noindent
  \\
  \rule[2em]{\linewidth}{.4pt}
  \par\vspace*{-8.7mm}
  \begin{center}%
    {\selectlanguage{french}%
      \normalfont\bfseries%
      \MakeUppercase{\@ftitle}%
      \par}%
  \end{center}}
\newcommand{\maketitleb}{%
  \ifthenelse{\boolean{englishprimary}}{\makeftitle}{\makeetitle}%
}

\RequirePackage{titlesec}
\titleformat{\section}
  {\bfseries\RaggedRight}
  {\thesection.}{0.2em}{\MakeUppercase}
\titlespacing*{\section}{0pt}{12pt}{6pt}

\titleformat{\subsection}
  {\bfseries\RaggedRight}
  {\thesubsection.}{0.2em}{}
\titlespacing*{\subsection}{0pt}{12pt}{0pt}

\titleformat{\subsubsection}
  {\bfseries\RaggedRight}
  {\thesubsubsection.}{0.2em}{}
\titlespacing*{\subsubsection}{0pt}{12pt}{0pt}

\newcommand{\keywords}[1]{\vskip 1.45em%
  \ifthenelse{\boolean{englishprimary}}{%
    \foreignlanguage{english}{\noindent\textbf{Keywords: } #1.}}{%
    \foreignlanguage{french}{\noindent\textbf{Mots-cl\'{e}s : } #1.}}}
\newcommand{\keywordsb}[1]{\vskip 1.45em%
  \ifthenelse{\boolean{englishprimary}}{%
    \foreignlanguage{french}{\noindent\textbf{Mots-cl\'{e}s : } #1.}}{%
    \foreignlanguage{english}{\noindent\textbf{Keywords: } #1.}}}


\RequirePackage{scrpage2}
%\RequirePackage{scrlayer-scrpage}
\setkomafont{pagefoot}{\normalfont\footnotesize}
\pagestyle{scrheadings}
\clearscrheadings
\rofoot{2023 CCToMM Mechanisms, Machines, and Mechatronics (M$^3$) Symposium%
 \hfill\pagemark\\[-1.5ex]
  \hrulefill}
  \refoot{\pagemark \hfill 2023 CCToMM Mechanisms, Machines, and Mechatronics (M$^3$) Symposium %
 \\[-1.5ex]
  \hrulefill}

\RequirePackage[font=small,labelsep=period]{caption}
    \captionsetup{figurename=Fig. , tablename=Table}

\newcommand*{\affn}[1]{%
  {\normalfont{\textsuperscript{#1}}}%
  \addtocounter{footnote}{1}%
}

\renewcommand{\bibfont}{\small}
\renewcommand{\bibnumfmt}[1]{#1.\hspace*{0.5em}}
\setlength{\bibsep}{0mm}

%% Close class file:
\endinput
%% End of ``tcsme.cls''
